.. _K54R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k54r.f
.. _K48R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k48r.f
.. _K70R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k70r.f
.. _K77R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k77r.f
.. _K86R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k86r.f
.. _K32R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k32r.f
.. _K58R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k58r.f
.. _K61R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k61r.f
.. _K89R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k89r.f
.. _K36R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k36r.f
.. _K41R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k41r.f
.. _K74R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/K74R.f
.. _K81R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k81r.f
.. _K91R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k91r.f
.. _K55R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k55r.f
.. _K50R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k50r.f
.. _K39R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k39r.f
.. _K46R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k46r.f
.. _KRANDOMC: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/KRandomC.f
.. _KROWFUNCTION: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/KRowFunction.f
.. _K47R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k47r.f
.. _K73R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/K73R.f
.. _K74RXX: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/K74RXX.f
.. _KTITFORTATC: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/KTitForTatC.f
.. _K42R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k42r.f
.. _K34R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k34r.f
.. _K67R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k67r.f
.. _K71R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k71r.f
.. _KCOLFUNCTION: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/KColFunction.f
.. _K93R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k93r.f
.. _K40R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k40r.f
.. _K84R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k84r.f
.. _K76R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k76r.f
.. _K68R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k68r.f
.. _K66R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k66r.f
.. _K44R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k44r.f
.. _K38R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k38r.f
.. _K63R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k63r.f
.. _GRASR: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/grasr.f
.. _K87R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k87r.f
.. _K45R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k45r.f
.. _K49R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k49r.f
.. _K62R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k62r.f
.. _K59R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/K59R.f
.. _K72R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k72r.f
.. _K90R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k90r.f
.. _K33R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k33r.f
.. _K69R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k69r.f
.. _K65R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k65r.f
.. _K79R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k79r.f
.. _K75R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/K75R.f
.. _K35R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k35r.f
.. _K78R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k78r.f
.. _K85R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k85r.f
.. _K80R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k80r.f
.. _K92R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/K92R.f
.. _K43R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k43r.f
.. _K82R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k82r.f
.. _KTF2TC: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/KTF2TC.f
.. _K64R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k64r.f
.. _K60R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k60r.f
.. _KPAVLOVC: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/KPavlovC.f
.. _K83R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k83r.f
.. _K52R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k52r.f
.. _K51R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k51r.f
.. _AXTEST: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/AxTest.f
.. _K57R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k57r.f
.. _K53R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k53r.f
.. _K37R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k37r.f
.. _K88R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k88r.f
.. _K56R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k56r.f
.. _K31R: https://github.com/Axelrod-Python/TourExec/blob/v0.2.0/src/strategies/k31r.f
